import React from 'react';
import { backgroundColor } from '@atlaskit/adf-schema';
import { changeColor } from './commands';
import { keymapPlugin } from './pm-plugins/keymap';
import { createPlugin, highlightPluginKey } from './pm-plugins/main';
import { FloatingToolbarHighlightColorWithIntl as FloatingToolbarHighlightColor } from './ui/FloatingToolbarHighlightColor';
import { PrimaryToolbarHighlightColorWithIntl as PrimaryToolbarHighlightColor } from './ui/PrimaryToolbarHighlightColor';
export const highlightPlugin = ({
  api,
  config: options
}) => {
  var _api$analytics, _api$primaryToolbar;
  const editorAnalyticsAPI = api === null || api === void 0 ? void 0 : (_api$analytics = api.analytics) === null || _api$analytics === void 0 ? void 0 : _api$analytics.actions;
  const primaryToolbarComponent = ({
    popupsMountPoint,
    popupsBoundariesElement,
    popupsScrollableElement,
    disabled,
    isToolbarReducedSpacing,
    editorView
  }) => /*#__PURE__*/React.createElement(PrimaryToolbarHighlightColor, {
    popupsMountPoint: popupsMountPoint,
    popupsBoundariesElement: popupsBoundariesElement,
    popupsScrollableElement: popupsScrollableElement,
    disabled: disabled,
    isToolbarReducedSpacing: isToolbarReducedSpacing,
    pluginInjectionApi: api,
    editorView: editorView
  });
  api === null || api === void 0 ? void 0 : (_api$primaryToolbar = api.primaryToolbar) === null || _api$primaryToolbar === void 0 ? void 0 : _api$primaryToolbar.actions.registerComponent({
    name: 'highlight',
    component: primaryToolbarComponent
  });
  return {
    name: 'highlight',
    marks() {
      return [{
        name: 'backgroundColor',
        mark: backgroundColor
      }];
    },
    commands: {
      changeColor: changeColor(editorAnalyticsAPI)
    },
    pmPlugins: () => [{
      name: 'highlight',
      plugin: () => createPlugin({
        api
      })
    }, {
      name: 'highlightKeymap',
      plugin: () => keymapPlugin({
        api
      })
    }],
    getSharedState(editorState) {
      if (!editorState) {
        return;
      }
      return highlightPluginKey.getState(editorState);
    },
    pluginsOptions: {
      selectionToolbar() {
        if (!(options !== null && options !== void 0 && options.textHighlightingFloatingToolbarExperiment)) {
          return;
        }
        const toolbarCustom = {
          type: 'custom',
          render: (_view, _idx, dispatchAnalyticsEvent) => /*#__PURE__*/React.createElement(FloatingToolbarHighlightColor, {
            dispatchAnalyticsEvent: dispatchAnalyticsEvent,
            pluginInjectionApi: api
          }),
          fallback: []
        };
        return {
          rank: -9,
          isToolbarAbove: true,
          items: [toolbarCustom]
        };
      }
    },
    primaryToolbarComponent: !(api !== null && api !== void 0 && api.primaryToolbar) ? primaryToolbarComponent : undefined
  };
};